var express = require('express');
var nunjucks = require('nunjucks');
var numeral = require('numeral');

var config = require('./config.json');

var app = express();
app.use(express.static('public', {maxAge: 24 * 3600 * 1000}));

var db = require('./db');
db.init({config: config});

var modelOptions = {config: config, db: db};
var storeUser = require('./store-user')
storeUser.init(modelOptions);

var trans = require('./trans');
trans.init(modelOptions);

var sales = require('./sales');
sales.init(modelOptions);

function isValidApiKey(apikey) {
    return config.apikey.indexOf(apikey) >= 0;
}

var checkAuth = function(req, res, next) {
    if (!isValidApiKey(req.params.apikey)) {
        res.end("Invalid auth: " + req.params.apikey);
        return;
    }
    next();
}

nunjucksEnv = nunjucks.configure('views', {
    autoescape: true,
    express: app,
    noCache: config.template_no_cache
});

nunjucksEnv.addFilter('numeral', function(num) {
    return numeral(num).format();
})


app.use("/apikey/:apikey", checkAuth);

app.get("/apikey/:apikey/store-user/by-msisdn/:msisdn", storeUser.getByMSISDN);
app.get("/apikey/:apikey/trans/by-messageid/:messageid", trans.getByMessageid);

app.get("/apikey/:apikey/sales/last-hour/per-chip-info", sales.getLastHoursSalesPerChipInfo);
app.get("/apikey/:apikey/sales/last-hour/per-chip-info/:hour", sales.getLastHoursSalesPerChipInfo);

app.get("/apikey/:apikey/sales/last-hour/per-product", sales.getLastHoursSalesPerProduct);
app.get("/apikey/:apikey/sales/last-hour/per-product/:hour", sales.getLastHoursSalesPerProduct);

app.get("/apikey/:apikey/sales/last-hour/per-customer", sales.getLastHoursSalesPerCustomer);
app.get("/apikey/:apikey/sales/last-hour/per-customer/:hour", sales.getLastHoursSalesPerCustomer);


app.listen(config.listen_port);
